@@ -12,7 +12,11 @@
 #include <QSortFilterProxyModel>
 #include <QStandardItemModel>
 #include <QVBoxLayout>
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
 #include <TextAddonsWidgets/LineEditCatchReturnKey>
+#else
+#include <KLineEditEventHandler>
+#endif
 using namespace TextTranslator;
 
 TranslatorConfigureLanguageListWidget::TranslatorConfigureLanguageListWidget(const QString &labelText, QWidget *parent)
@@ -44,7 +48,11 @@ TranslatorConfigureLanguageListWidget::TranslatorConfigureLanguageListWidget(con
     mLanguageListWidget->setObjectName(QStringLiteral("mLanguageListWidget"));
     mainLayout->addWidget(mLanguageListWidget);
     mLanguageListWidget->setModel(filterProxyModel);
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
     new TextAddonsWidgets::LineEditCatchReturnKey(mListSearchLine, this);
+#else
+    KLineEditEventHandler::catchReturnKey(mListSearchLine);
+#endif
 }
 
 TranslatorConfigureLanguageListWidget::~TranslatorConfigureLanguageListWidget() = default;
@@ -84,3 +92,5 @@ void TranslatorConfigureLanguageListWidget::setSelectedLanguages(const QStringLi
         item->setCheckState(list.contains(item->data(LanguageCode).toString()) ? Qt::Checked : Qt::Unchecked);
     }
 }
+
+#include "moc_translatorconfigurelanguagelistwidget.cpp"
